summaryrefslogtreecommitdiffstats
path: root/kalyptus/kalyptusCxxToKimono.pm
diff options
context:
space:
mode:
Diffstat (limited to 'kalyptus/kalyptusCxxToKimono.pm')
-rw-r--r--kalyptus/kalyptusCxxToKimono.pm23
1 files changed, 6 insertions, 17 deletions
diff --git a/kalyptus/kalyptusCxxToKimono.pm b/kalyptus/kalyptusCxxToKimono.pm
index 089cec92..4f4804c2 100644
--- a/kalyptus/kalyptusCxxToKimono.pm
+++ b/kalyptus/kalyptusCxxToKimono.pm
@@ -82,10 +82,7 @@ BEGIN
'TQ_UINT64' => '$',
'TQ_INT64' => '$',
'TQ_LLONG' => '$',
- 'tquint64' => '$',
- 'qint64' => '$',
'long long' => '$',
- 'qulonglong' => '$',
);
# Yes some of this is in kalyptusDataDict's ctypemap
@@ -147,21 +144,13 @@ BEGIN
'TQStyle::SCFlags' => 'int',
'TQStyle::SFlags' => 'int',
'TQ_INT16' => 'short',
- 'qint16' => 'short',
'TQ_INT32' => 'int',
- 'qint32' => 'int',
- 'qint32&' => 'int&',
'TQ_INT8' => 'char',
- 'qint8' => 'char',
'TQ_LONG' => 'long',
'TQ_UINT16' => 'ushort',
- 'tquint16' => 'ushort',
'TQ_UINT32' => 'uint',
- 'tquint32' => 'uint',
'TQ_UINT8' => 'uchar',
- 'tquint8' => 'uchar',
'TQ_ULONG' => 'long',
- 'qreal' => 'double',
'pid_t' => 'int',
'size_t' => 'int',
'pid_t' => 'int',
@@ -397,11 +386,11 @@ EOF
public static TQApplication tqApp = null;
- public static string SIGNAL(string signal) {
+ public static string TQ_SIGNAL(string signal) {
return "2"+ signal;
}
- public static string SLOT(string slot) {
+ public static string TQ_SLOT(string slot) {
return "1" + slot;
}
EOF
@@ -952,7 +941,7 @@ sub preParseClass
|| ($name eq 'type')
|| ($classNode->{astNodeName} eq 'KTar' and $name eq 'writeFile_impl')
|| ($classNode->{astNodeName} eq 'TQApplication' and $name eq 'TQApplication')
# Assume only Qt classes have tr() and trUtf8() in their Q_OBJECT macro
|| ($classNode->{astNodeName} !~ /^Q/ and $name eq 'tr')
|| ($classNode->{astNodeName} !~ /^Q/ and $name eq 'trUtf8')
@@ -3508,9 +3497,9 @@ sub printCSharpdocComment($$$$)
$line =~ s/const char/string/g;
$line =~ s/const (\w+)\&/$1/g;
$line =~ s/bool/bool/g;
- $line =~ s/SLOT\(\s*([^\)]*)\) ?\)/SLOT("$1)")/g;
- $line =~ s/SIGNAL\(\s*([^\)]*)\) ?\)/SIGNAL("$1)")/g;
- $line =~ s/Q_OBJECT\n//g;
+ $line =~ s/TQ_SLOT\(\s*([^\)]*)\) ?\)/TQ_SLOT("$1)")/g;
+ $line =~ s/TQ_SIGNAL\(\s*([^\)]*)\) ?\)/TQ_SIGNAL("$1)")/g;
+ $line =~ s/TQ_OBJECT\n//g;
$line =~ s/public\s*(slots)?:\n/public /g;
$line =~ s/([^0-9"]\s*)\*(\s*[^0-9"-])/$1$2/g;
$line =~ s/^(\s*)\*/$1/g;
@@ -952,7 +941,7 @@ sub preParseClass
|| ($classNode->{astNodeName} eq 'KTar' and $name eq 'writeFile_impl')
|| ($classNode->{astNodeName} eq 'TQApplication' and $name eq 'TQApplication')
- # Assume only Qt classes have tr() and trUtf8() in their Q_OBJECT macro
+ # Assume only Qt classes have tr() and trUtf8() in their TQ_OBJECT macro
|| ($classNode->{astNodeName} !~ /^Q/ and $name eq 'tr')
|| ($classNode->{astNodeName} !~ /^Q/ and $name eq 'trUtf8')